Title Page

# Family Life and Work Experience Before 1918, 1870-1973

## Study number: 2000

## Principal Investigators

## Thompson, P., Lummis, T., University of Essex. Department of Sociology

## Sponsor

## Economic and Social Research Council

## Distributed by

## UK Data Archive, University of Essex, Colchester. May 2009 (7th Edition)

## Citation for this data

## All works which use or refer to these materials should acknowledge these sources by means of data citation. To ensure that such source attributions are captured for citation indexes, citations must appear in footnotes or in the reference section of publications. The citation for this data collection is:

## Thompson, P. and Lummis, T., Family Life and Work Experience Before 1918, 1870-1973 [computer file]. 7th Edition. Colchester, Essex: UK Data Archive [distributor], May 2009. SN: 2000.

## Copyright

## P. Thompson, University of Essex. Database right P. Thompson, University of Essex and UK Data Service, University of Essex, 2006

## Disclaimer

## Although all efforts are made to ensure the quality of the materials, neither the original data creators, depositors or copyright holders, the funders of the Data Collections, nor the UK Data Archive bear any responsibility for the accuracy or comprehensiveness of these materials.

## File last updated: 4 June 2015